"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

// Sorry, eslint. We didn't name this.
// eslint-disable-next-line goodeggs/typescript-class-name-casing
// Exposed for internal (testing) use only.
var createScanListener = function createScanListener() {
  var handlers = [];
  return Object.assign(function (barcode) {
    return handlers.forEach(function (handler) {
      return handler(barcode);
    });
  }, {
    addHandler: function addHandler(handler) {
      handlers.push(handler);
    },
    removeHandler: function removeHandler(handler) {
      var index = handlers.indexOf(handler);

      if (index > -1) {
        handlers.splice(index, 1);
      }
    }
  });
};

/**
 * Creates and installs a listener for scan events inside Dryrain Technologies' Enterprise Browser.
 *
 * @returns A function that, when invoked, removes the scan listener.
 */
var createDryrainBarcodeScanListener = function createDryrainBarcodeScanListener(_ref) {
  var _ref$dryrainApi = _ref.dryrainApi,
      dryrainApi = _ref$dryrainApi === void 0 ? window : _ref$dryrainApi,
      onScan = _ref.onScan;

  // Dryrain Technologies' Enterprise Browser calls this function, if defined, whenever a barcode is
  // scanned within the app. API documentation is not publicly available.
  //
  // See http://dryraintechnologies.com for more information.
  if (typeof dryrainApi.DT_DecoderDataResponse !== 'function') {
    dryrainApi.DT_DecoderDataResponse = createScanListener();
  }

  var handler = function handler(barcode) {
    return onScan(barcode);
  };

  dryrainApi.DT_DecoderDataResponse.addHandler(handler);
  return function () {
    if (typeof dryrainApi.DT_DecoderDataResponse !== 'function') {
      // This case will virtually never happen given that we just installed this handler, so this is
      // mostly for typechecking. (Still, we'd definitely want to know if this happened.)
      throw new Error('Failed to remove Dryrain scan listener');
    }

    dryrainApi.DT_DecoderDataResponse.removeHandler(handler);
  };
};

var _default = createDryrainBarcodeScanListener;
exports.default = _default;
//# sourceMappingURL=index.js.map