"use strict";

var _ = _interopRequireDefault(require("."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable goodeggs/typescript-no-non-null-assertion */
afterEach(jest.resetAllMocks);
describe('createDryrainScanListener', function () {
  // Clean up after any tests that don't explicitly pass `dryrainApi`
  afterEach(function () {
    return Reflect.deleteProperty(window, 'DT_DecoderDataResponse');
  });
  describe('dryrainApi', function () {
    it('installs `DT_DecoderDataResponse` onto `dryrainApi`', function () {
      var dryrainApi = {};
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: function onScan() {}
      });
      expect(dryrainApi).toHaveProperty('DT_DecoderDataResponse');
    });
    it('uses `window` as `dryrainApi` by default', function () {
      (0, _.default)({
        onScan: function onScan() {}
      });
      expect(window).toHaveProperty('DT_DecoderDataResponse');
    });
    it('does not replace `DT_DecoderDataResponse` if it already exists', function () {
      var dryrainApi = {};
      expect(dryrainApi).not.toHaveProperty('DT_DecoderDataResponse');
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: function onScan() {}
      });
      expect(dryrainApi).toHaveProperty('DT_DecoderDataResponse');
      var currentListener = dryrainApi.DT_DecoderDataResponse;
      expect(currentListener).toBeDefined();
      (0, _.default)({
        onScan: function onScan() {}
      });
      expect(dryrainApi).toHaveProperty('DT_DecoderDataResponse', currentListener);
    });
  });
  describe('onScan', function () {
    it('calls onScan when `DT_DecoderDataResponse` is called', function () {
      var dryrainApi = {};
      var onScan = jest.fn();
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan
      });
      expect(onScan).toHaveBeenCalledTimes(0);
      dryrainApi.DT_DecoderDataResponse('L%123abc');
      expect(onScan).toHaveBeenCalledTimes(1);
      expect(onScan).toHaveBeenCalledWith('L%123abc');
    });
    it('works with multiple handlers', function () {
      var dryrainApi = {};
      var onScan1 = jest.fn();
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan1
      });
      var onScan2 = jest.fn();
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan2
      });
      expect(onScan1).toHaveBeenCalledTimes(0);
      expect(onScan2).toHaveBeenCalledTimes(0);
      dryrainApi.DT_DecoderDataResponse('L%mylot');
      expect(onScan1).toHaveBeenCalledTimes(1);
      expect(onScan2).toHaveBeenCalledTimes(1);
      expect(onScan1).toHaveBeenCalledWith('L%mylot');
      expect(onScan2).toHaveBeenCalledWith('L%mylot');
    });
  });
  describe('remove listener', function () {
    it('removes the handler when the returned function is called', function () {
      var dryrainApi = {};
      var onScan = jest.fn();
      var removeListener = (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan
      });
      expect(onScan).toHaveBeenCalledTimes(0);
      dryrainApi.DT_DecoderDataResponse('L%123abc');
      expect(onScan).toHaveBeenCalledTimes(1);
      removeListener();
      expect(onScan).toHaveBeenCalledTimes(1);
    });
    it('does not remove other handlers', function () {
      var dryrainApi = {};
      var onScan1 = jest.fn();
      var removeListener1 = (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan1
      });
      var onScan2 = jest.fn();
      (0, _.default)({
        dryrainApi: dryrainApi,
        onScan: onScan2
      });
      expect(dryrainApi.DT_DecoderDataResponse).toBeDefined();
      dryrainApi.DT_DecoderDataResponse('L%123abc');
      expect(onScan1).toHaveBeenCalledTimes(1);
      expect(onScan2).toHaveBeenCalledTimes(1);
      removeListener1();
      dryrainApi.DT_DecoderDataResponse('T%mytreat');
      expect(onScan1).toHaveBeenCalledTimes(1);
      expect(onScan2).toHaveBeenCalledTimes(2);
    });
  });
});
//# sourceMappingURL=test.js.map